# generated by datamodel-codegen:
#   filename:  accounts.json
#   timestamp: 2024-09-02T14:02:23+00:00

from __future__ import annotations

from datetime import datetime
from enum import Enum
from typing import Optional

from pydantic import Field

from . import CanvasBaseModel



class Account(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[2])
    """
    the ID of the Account object
    """

    name: Optional[str] = Field(None, examples=['Canvas Account'])
    """
    The display name of the account
    """

    uuid: Optional[str] = Field(
        None, examples=['WvAHhY5FINzq5IyRIJybGeiXyFkG3SqHUPb7jZY5'], repr=False
    )
    """
    The UUID of the account
    """

    parent_account_id: Optional[int] = Field(None, examples=[1], repr=False)
    """
    The account's parent ID, or null if this is the root account
    """

    root_account_id: Optional[int] = Field(None, examples=[1], repr=False)
    """
    The ID of the root account, or null if this is the root account
    """

    default_storage_quota_mb: Optional[int] = Field(None, examples=[500], repr=False)
    """
    The storage quota for the account in megabytes, if not otherwise specified
    """

    default_user_storage_quota_mb: Optional[int] = Field(
        None, examples=[50], repr=False
    )
    """
    The storage quota for a user in the account in megabytes, if not otherwise specified
    """

    default_group_storage_quota_mb: Optional[int] = Field(
        None, examples=[50], repr=False
    )
    """
    The storage quota for a group in the account in megabytes, if not otherwise specified
    """

    default_time_zone: Optional[str] = Field(
        None, examples=['America/Denver'], repr=False
    )
    """
    The default time zone of the account. Allowed time zones are {http://www.iana.org/time-zones IANA time zones} or friendlier {http://api.rubyonrails.org/classes/ActiveSupport/TimeZone.html Ruby on Rails time zones}.
    """

    sis_account_id: Optional[str] = Field(None, examples=['123xyz'], repr=False)
    """
    The account's identifier in the Student Information System. Only included if the user has permission to view SIS information.
    """

    integration_id: Optional[str] = Field(None, examples=['123xyz'], repr=False)
    """
    The account's identifier in the Student Information System. Only included if the user has permission to view SIS information.
    """

    sis_import_id: Optional[int] = Field(None, examples=['12'], repr=False)
    """
    The id of the SIS import if created through SIS. Only included if the user has permission to manage SIS information.
    """

    course_count: Optional[int] = Field(None, examples=['10'], repr=False)
    """
    The number of courses directly under the account (available via include)
    """

    sub_account_count: Optional[int] = Field(None, examples=['10'], repr=False)
    """
    The number of sub-accounts directly under the account (available via include)
    """

    lti_guid: Optional[str] = Field(None, examples=['123xyz'], repr=False)
    """
    The account's identifier that is sent as context_id in LTI launches.
    """

    workflow_state: Optional[str] = Field(None, examples=['active'], repr=False)
    """
    The state of the account. Can be 'active' or 'deleted'.
    """



class TermsType(Enum):
    default = 'default'
    custom = 'custom'
    no_terms = 'no_terms'


class TermsOfService(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[1])
    """
    Terms Of Service id
    """

    terms_type: Optional[TermsType] = Field(None, examples=['default'])
    """
    The given type for the Terms of Service
    """

    passive: Optional[bool] = Field(None, examples=[False])
    """
    Boolean dictating if the user must accept Terms of Service
    """

    account_id: Optional[int] = Field(None, examples=[1])
    """
    The id of the root account that owns the Terms of Service
    """

    content: Optional[str] = Field(
        None, examples=['To be or not to be that is the question']
    )
    """
    Content of the Terms of Service
    """

    self_registration_type: Optional[str] = Field(
        None, examples=[['none', 'observer', 'all']]
    )
    """
    The type of self registration allowed
    """



class Type(Enum):
    default = 'default'
    custom = 'custom'


class HelpLink(CanvasBaseModel):
    id: Optional[str] = Field(None, examples=['instructor_question'])
    """
    The ID of the help link
    """

    text: Optional[str] = Field(None, examples=['Ask Your Instructor a Question'])
    """
    The name of the help link
    """

    subtext: Optional[str] = Field(
        None, examples=['Questions are submitted to your instructor']
    )
    """
    The description of the help link
    """

    url: Optional[str] = Field(None, examples=['#teacher_feedback'])
    """
    The URL of the help link
    """

    type: Optional[Type] = Field(None, examples=['default'])
    """
    The type of the help link
    """

    available_to: Optional[list[str]] = Field(
        None,
        examples=[['user', 'student', 'teacher', 'admin', 'observer', 'unenrolled']],
    )
    """
    The roles that have access to this help link
    """



class HelpLinks(CanvasBaseModel):
    help_link_name: Optional[str] = Field(None, examples=['Help And Policies'])
    """
    Help link button title
    """

    help_link_icon: Optional[str] = Field(None, examples=['help'])
    """
    Help link button icon
    """

    custom_help_links: Optional[list[HelpLink]] = Field(
        None,
        examples=[
            [
                {
                    'id': 'link1',
                    'text': 'Custom Link!',
                    'subtext': 'Something something.',
                    'url': 'https://google.com',
                    'type': 'custom',
                    'available_to': [
                        'user',
                        'student',
                        'teacher',
                        'admin',
                        'observer',
                        'unenrolled',
                    ],
                    'is_featured': True,
                    'is_new': False,
                    'feature_headline': 'Check this out!',
                }
            ]
        ],
    )
    """
    Help links defined by the account. Could include default help links.
    """

    default_help_links: Optional[list[HelpLink]] = Field(
        None,
        examples=[
            [
                {
                    'available_to': ['student'],
                    'text': 'Ask Your Instructor a Question',
                    'subtext': 'Questions are submitted to your instructor',
                    'url': '#teacher_feedback',
                    'type': 'default',
                    'id': 'instructor_question',
                    'is_featured': False,
                    'is_new': True,
                    'feature_headline': '',
                },
                {
                    'available_to': [
                        'user',
                        'student',
                        'teacher',
                        'admin',
                        'observer',
                        'unenrolled',
                    ],
                    'text': 'Search the Canvas Guides',
                    'subtext': 'Find answers to common questions',
                    'url': 'https://community.canvaslms.com/t5/Guides/ct-p/guides',
                    'type': 'default',
                    'id': 'search_the_canvas_guides',
                    'is_featured': False,
                    'is_new': False,
                    'feature_headline': '',
                },
                {
                    'available_to': [
                        'user',
                        'student',
                        'teacher',
                        'admin',
                        'observer',
                        'unenrolled',
                    ],
                    'text': 'Report a Problem',
                    'subtext': 'If Canvas misbehaves, tell us about it',
                    'url': '#create_ticket',
                    'type': 'default',
                    'id': 'report_a_problem',
                    'is_featured': False,
                    'is_new': False,
                    'feature_headline': '',
                },
            ]
        ],
    )
    """
    Default help links provided when account has not set help links of their own.
    """

