# generated by datamodel-codegen:
#   filename:  assignments.json
#   timestamp: 2024-09-02T14:02:23+00:00

from __future__ import annotations

from datetime import datetime
from typing import Any, Optional

from pydantic import Field

from . import CanvasBaseModel



class ExternalToolTagAttributes(CanvasBaseModel):
    url: Optional[str] = Field(None, examples=['http://instructure.com'])
    """
    URL to the external tool
    """

    new_tab: Optional[bool] = Field(None, examples=[False])
    """
    Whether or not there is a new tab for the external tool
    """

    resource_link_id: Optional[str] = Field(None, examples=['ab81173af98b8c33e66a'])
    """
    the identifier for this tool_tag
    """



class LockInfo(CanvasBaseModel):
    asset_string: Optional[str] = Field(None, examples=['assignment_4'])
    """
    Asset string for the object causing the lock
    """

    unlock_at: Optional[datetime] = Field(None, examples=['2013-01-01T00:00:00-06:00'])
    """
    (Optional) Time at which this was/will be unlocked. Must be before the due date.
    """

    lock_at: Optional[datetime] = Field(None, examples=['2013-02-01T00:00:00-06:00'])
    """
    (Optional) Time at which this was/will be locked. Must be after the due date.
    """

    context_module: Optional[str] = Field(None, examples=['{}'])
    """
    (Optional) Context module causing the lock.
    """

    manually_locked: Optional[bool] = Field(None, examples=[True])


class RubricRating(CanvasBaseModel):
    points: Optional[int] = Field(None, examples=[10])
    id: Optional[str] = Field(None, examples=['rat1'])
    description: Optional[str] = Field(None, examples=['Full marks'])
    long_description: Optional[str] = Field(
        None, examples=['Student completed the assignment flawlessly.']
    )


class AssignmentDate(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[1])
    """
    (Optional, missing if 'base' is present) id of the assignment override this date represents
    """

    base: Optional[bool] = Field(None, examples=[True])
    """
    (Optional, present if 'id' is missing) whether this date represents the assignment's or quiz's default due date
    """

    title: Optional[str] = Field(None, examples=['Summer Session'])
    due_at: Optional[datetime] = Field(None, examples=['2013-08-28T23:59:00-06:00'])
    """
    The due date for the assignment. Must be between the unlock date and the lock date if there are lock dates
    """

    unlock_at: Optional[datetime] = Field(None, examples=['2013-08-01T00:00:00-06:00'])
    """
    The unlock date for the assignment. Must be before the due date if there is a due date.
    """

    lock_at: Optional[datetime] = Field(None, examples=['2013-08-31T23:59:00-06:00'])
    """
    The lock date for the assignment. Must be after the due date if there is a due date.
    """



class TurnitinSettings(CanvasBaseModel):
    originality_report_visibility: Optional[str] = Field(
        None, examples=['after_grading']
    )
    s_paper_check: Optional[bool] = Field(None, examples=[False])
    internet_check: Optional[bool] = Field(None, examples=[False])
    journal_check: Optional[bool] = Field(None, examples=[False])
    exclude_biblio: Optional[bool] = Field(None, examples=[False])
    exclude_quoted: Optional[bool] = Field(None, examples=[False])
    exclude_small_matches_type: Optional[str] = Field(None, examples=['percent'])
    exclude_small_matches_value: Optional[int] = Field(None, examples=[50])


class NeedsGradingCount(CanvasBaseModel):
    section_id: Optional[str] = Field(None, examples=['123456'])
    """
    The section ID
    """

    needs_grading_count: Optional[int] = Field(None, examples=[5])
    """
    Number of submissions that need grading
    """



class ScoreStatistic(CanvasBaseModel):
    min: Optional[int] = Field(None, examples=[1])
    """
    Min score
    """

    max: Optional[int] = Field(None, examples=[10])
    """
    Max score
    """

    mean: Optional[int] = Field(None, examples=[6])
    """
    Mean score
    """

    upper_q: Optional[int] = Field(None, examples=[10])
    """
    Upper quartile score
    """

    median: Optional[int] = Field(None, examples=[6])
    """
    Median score
    """

    lower_q: Optional[int] = Field(None, examples=[1])
    """
    Lower quartile score
    """



class AssignmentOverride(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[4])
    """
    the ID of the assignment override
    """

    assignment_id: Optional[int] = Field(None, examples=[123], repr=False)
    """
    the ID of the assignment the override applies to (present if the override applies to an assignment)
    """

    quiz_id: Optional[int] = Field(None, examples=[123], repr=False)
    """
    the ID of the quiz the override applies to (present if the override applies to a quiz)
    """

    context_module_id: Optional[int] = Field(None, examples=[123], repr=False)
    """
    the ID of the module the override applies to (present if the override applies to a module)
    """

    discussion_topic_id: Optional[int] = Field(None, examples=[123], repr=False)
    """
    the ID of the discussion the override applies to (present if the override applies to an ungraded discussion)
    """

    wiki_page_id: Optional[int] = Field(None, examples=[123], repr=False)
    """
    the ID of the page the override applies to (present if the override applies to a page)
    """

    attachment_id: Optional[int] = Field(None, examples=[123], repr=False)
    """
    the ID of the file the override applies to (present if the override applies to a file)
    """

    student_ids: Optional[list[int]] = Field(None, examples=[[1, 2, 3]], repr=False)
    """
    the IDs of the override's target students (present if the override targets an ad-hoc set of students)
    """

    group_id: Optional[int] = Field(None, examples=[2], repr=False)
    """
    the ID of the override's target group (present if the override targets a group and the assignment is a group assignment)
    """

    course_section_id: Optional[int] = Field(None, examples=[1], repr=False)
    """
    the ID of the overrides's target section (present if the override targets a section)
    """

    title: Optional[str] = Field(None, examples=['an assignment override'])
    """
    the title of the override
    """

    due_at: Optional[datetime] = Field(
        None, examples=['2012-07-01T23:59:00-06:00'], repr=False
    )
    """
    the overridden due at (present if due_at is overridden)
    """

    all_day: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    the overridden all day flag (present if due_at is overridden)
    """

    all_day_date: Optional[datetime] = Field(None, examples=['2012-07-01'], repr=False)
    """
    the overridden all day date (present if due_at is overridden)
    """

    unlock_at: Optional[datetime] = Field(
        None, examples=['2012-07-01T23:59:00-06:00'], repr=False
    )
    """
    the overridden unlock at (present if unlock_at is overridden)
    """

    lock_at: Optional[datetime] = Field(
        None, examples=['2012-07-01T23:59:00-06:00'], repr=False
    )
    """
    the overridden lock at, if any (present if lock_at is overridden)
    """



class RubricCriteria(CanvasBaseModel):
    points: Optional[int] = Field(None, examples=[10])
    id: Optional[str] = Field(None, examples=['crit1'])
    """
    The id of rubric criteria.
    """

    learning_outcome_id: Optional[str] = Field(None, examples=['1234'])
    """
    (Optional) The id of the learning outcome this criteria uses, if any.
    """

    vendor_guid: Optional[str] = Field(None, examples=['abdsfjasdfne3jsdfn2'])
    """
    (Optional) The 3rd party vendor's GUID for the outcome this criteria references, if any.
    """

    description: Optional[str] = Field(None, examples=['Criterion 1'])
    long_description: Optional[str] = Field(None, examples=['Criterion 1 more details'])
    criterion_use_range: Optional[bool] = Field(None, examples=[True])
    ratings: Optional[list[RubricRating_1]] = None
    ignore_for_scoring: Optional[bool] = Field(None, examples=[True])


class Assignment(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[4])
    """
    the ID of the assignment
    """

    name: Optional[str] = Field(None, examples=['some assignment'])
    """
    the name of the assignment
    """

    description: Optional[str] = Field(
        None, examples=['<p>Do the following:</p>...'], repr=False
    )
    """
    the assignment description, in an HTML fragment
    """

    created_at: Optional[datetime] = Field(
        None, examples=['2012-07-01T23:59:00-06:00'], repr=False
    )
    """
    The time at which this assignment was originally created
    """

    updated_at: Optional[datetime] = Field(
        None, examples=['2012-07-01T23:59:00-06:00'], repr=False
    )
    """
    The time at which this assignment was last modified in any way
    """

    due_at: Optional[datetime] = Field(
        None, examples=['2012-07-01T23:59:00-06:00'], repr=False
    )
    """
    the due date for the assignment. returns null if not present. NOTE: If this assignment has assignment overrides, this field will be the due date as it applies to the user requesting information from the API.
    """

    lock_at: Optional[datetime] = Field(
        None, examples=['2012-07-01T23:59:00-06:00'], repr=False
    )
    """
    the lock date (assignment is locked after this date). returns null if not present. NOTE: If this assignment has assignment overrides, this field will be the lock date as it applies to the user requesting information from the API.
    """

    unlock_at: Optional[datetime] = Field(
        None, examples=['2012-07-01T23:59:00-06:00'], repr=False
    )
    """
    the unlock date (assignment is unlocked after this date) returns null if not present NOTE: If this assignment has assignment overrides, this field will be the unlock date as it applies to the user requesting information from the API.
    """

    has_overrides: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    whether this assignment has overrides
    """

    all_dates: Optional[list[AssignmentDate]] = Field(None, repr=False)
    """
    (Optional) all dates associated with the assignment, if applicable
    """

    course_id: Optional[int] = Field(None, examples=[123], repr=False)
    """
    the ID of the course the assignment belongs to
    """

    html_url: Optional[str] = Field(None, examples=['https://...'], repr=False)
    """
    the URL to the assignment's web page
    """

    submissions_download_url: Optional[str] = Field(
        None,
        examples=[
            'https://example.com/courses/:course_id/assignments/:id/submissions?zip=1'
        ],
        repr=False,
    )
    """
    the URL to download all submissions as a zip
    """

    assignment_group_id: Optional[int] = Field(None, examples=[2], repr=False)
    """
    the ID of the assignment's group
    """

    due_date_required: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    Boolean flag indicating whether the assignment requires a due date based on the account level setting
    """

    allowed_extensions: Optional[list[str]] = Field(
        None, examples=[['docx', 'ppt']], repr=False
    )
    """
    Allowed file extensions, which take effect if submission_types includes 'online_upload'.
    """

    max_name_length: Optional[int] = Field(None, examples=[15], repr=False)
    """
    An integer indicating the maximum length an assignment's name may be
    """

    turnitin_enabled: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    Boolean flag indicating whether or not Turnitin has been enabled for the assignment. NOTE: This flag will not appear unless your account has the Turnitin plugin available
    """

    vericite_enabled: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    Boolean flag indicating whether or not VeriCite has been enabled for the assignment. NOTE: This flag will not appear unless your account has the VeriCite plugin available
    """

    turnitin_settings: Optional[TurnitinSettings] = Field(None, repr=False)
    """
    Settings to pass along to turnitin to control what kinds of matches should be considered. originality_report_visibility can be 'immediate', 'after_grading', 'after_due_date', or 'never' exclude_small_matches_type can be null, 'percent', 'words' exclude_small_matches_value: - if type is null, this will be null also - if type is 'percent', this will be a number between 0 and 100 representing match size to exclude as a percentage of the document size. - if type is 'words', this will be number > 0 representing how many words a match must contain for it to be considered NOTE: This flag will not appear unless your account has the Turnitin plugin available
    """

    grade_group_students_individually: Optional[bool] = Field(
        None, examples=[False], repr=False
    )
    """
    If this is a group assignment, boolean flag indicating whether or not students will be graded individually.
    """

    external_tool_tag_attributes: Optional[ExternalToolTagAttributes] = Field(
        None, repr=False
    )
    """
    (Optional) assignment's settings for external tools if submission_types include 'external_tool'. Only url and new_tab are included (new_tab defaults to false).  Use the 'External Tools' API if you need more information about an external tool.
    """

    peer_reviews: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Boolean indicating if peer reviews are required for this assignment
    """

    automatic_peer_reviews: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Boolean indicating peer reviews are assigned automatically. If false, the teacher is expected to manually assign peer reviews.
    """

    peer_review_count: Optional[int] = Field(None, examples=[0], repr=False)
    """
    Integer representing the amount of reviews each user is assigned. NOTE: This key is NOT present unless you have automatic_peer_reviews set to true.
    """

    peer_reviews_assign_at: Optional[datetime] = Field(
        None, examples=['2012-07-01T23:59:00-06:00'], repr=False
    )
    """
    String representing a date the reviews are due by. Must be a date that occurs after the default due date. If blank, or date is not after the assignment's due date, the assignment's due date will be used. NOTE: This key is NOT present unless you have automatic_peer_reviews set to true.
    """

    intra_group_peer_reviews: Optional[bool] = Field(
        None, examples=['false'], repr=False
    )
    """
    Boolean representing whether or not members from within the same group on a group assignment can be assigned to peer review their own group's work
    """

    group_category_id: Optional[int] = Field(None, examples=[1], repr=False)
    """
    The ID of the assignment’s group set, if this is a group assignment. For group discussions, set group_category_id on the discussion topic, not the linked assignment.
    """

    needs_grading_count: Optional[int] = Field(None, examples=[17], repr=False)
    """
    if the requesting user has grading rights, the number of submissions that need grading.
    """

    needs_grading_count_by_section: Optional[list[NeedsGradingCount]] = Field(
        None,
        examples=[
            [
                {'section_id': '123456', 'needs_grading_count': 5},
                {'section_id': '654321', 'needs_grading_count': 0},
            ]
        ],
        repr=False,
    )
    """
    if the requesting user has grading rights and the 'needs_grading_count_by_section' flag is specified, the number of submissions that need grading split out by section. NOTE: This key is NOT present unless you pass the 'needs_grading_count_by_section' argument as true.  ANOTHER NOTE: it's possible to be enrolled in multiple sections, and if a student is setup that way they will show an assignment that needs grading in multiple sections (effectively the count will be duplicated between sections)
    """

    position: Optional[int] = Field(None, examples=[1], repr=False)
    """
    the sorting order of the assignment in the group
    """

    post_to_sis: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    (optional, present if Sync Grades to SIS feature is enabled)
    """

    integration_id: Optional[str] = Field(None, examples=['12341234'], repr=False)
    """
    (optional, Third Party unique identifier for Assignment)
    """

    integration_data: Optional[dict[str, Any]] = Field(
        None, examples=[{'5678': '0954'}], repr=False
    )
    """
    (optional, Third Party integration data for assignment)
    """

    points_possible: Optional[float] = Field(None, examples=[12.0], repr=False)
    """
    the maximum points possible for the assignment
    """

    submission_types: Optional[list[str]] = Field(
        None, examples=[['online_text_entry']], repr=False
    )
    """
    the types of submissions allowed for this assignment list containing one or more of the following: 'discussion_topic', 'online_quiz', 'on_paper', 'none', 'external_tool', 'online_text_entry', 'online_url', 'online_upload', 'media_recording', 'student_annotation'
    """

    has_submitted_submissions: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    If true, the assignment has been submitted to by at least one student
    """

    grading_type: Optional[str] = Field(None, examples=['points'], repr=False)
    """
    The type of grading the assignment receives; one of 'pass_fail', 'percent', 'letter_grade', 'gpa_scale', 'points'
    """

    grading_standard_id: Optional[int] = Field(None, repr=False)
    """
    The id of the grading standard being applied to this assignment. Valid if grading_type is 'letter_grade' or 'gpa_scale'.
    """

    published: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    Whether the assignment is published
    """

    unpublishable: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Whether the assignment's 'published' state can be changed to false. Will be false if there are student submissions for the assignment.
    """

    only_visible_to_overrides: Optional[bool] = Field(
        None, examples=[False], repr=False
    )
    """
    Whether the assignment is only visible to overrides.
    """

    locked_for_user: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Whether or not this is locked for the user.
    """

    lock_info: Optional[LockInfo] = Field(None, repr=False)
    """
    (Optional) Information for the user about the lock. Present when locked_for_user is true.
    """

    lock_explanation: Optional[str] = Field(
        None,
        examples=['This assignment is locked until September 1 at 12:00am'],
        repr=False,
    )
    """
    (Optional) An explanation of why this is locked for the user. Present when locked_for_user is true.
    """

    quiz_id: Optional[int] = Field(None, examples=[620], repr=False)
    """
    (Optional) id of the associated quiz (applies only when submission_types is ['online_quiz'])
    """

    anonymous_submissions: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    (Optional) whether anonymous submissions are accepted (applies only to quiz assignments)
    """

    discussion_topic: Optional[DiscussionTopic] = Field(None, repr=False)
    """
    (Optional) the DiscussionTopic associated with the assignment, if applicable
    """

    freeze_on_copy: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    (Optional) Boolean indicating if assignment will be frozen when it is copied. NOTE: This field will only be present if the AssignmentFreezer plugin is available for your account.
    """

    frozen: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    (Optional) Boolean indicating if assignment is frozen for the calling user. NOTE: This field will only be present if the AssignmentFreezer plugin is available for your account.
    """

    frozen_attributes: Optional[list[str]] = Field(
        None, examples=[['title']], repr=False
    )
    """
    (Optional) Array of frozen attributes for the assignment. Only account administrators currently have permission to change an attribute in this list. Will be empty if no attributes are frozen for this assignment. Possible frozen attributes are: title, description, lock_at, points_possible, grading_type, submission_types, assignment_group_id, allowed_extensions, group_category_id, notify_of_update, peer_reviews NOTE: This field will only be present if the AssignmentFreezer plugin is available for your account.
    """

    submission: Optional[Submission] = Field(None, repr=False)
    """
    (Optional) If 'submission' is included in the 'include' parameter, includes a Submission object that represents the current user's (user who is requesting information from the api) current submission for the assignment. See the Submissions API for an example response. If the user does not have a submission, this key will be absent.
    """

    use_rubric_for_grading: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    (Optional) If true, the rubric is directly tied to grading the assignment. Otherwise, it is only advisory. Included if there is an associated rubric.
    """

    rubric_settings: Optional[dict[str, Any]] = Field(
        None, examples=[{'points_possible': '12'}], repr=False
    )
    """
    (Optional) An object describing the basic attributes of the rubric, including the point total. Included if there is an associated rubric.
    """

    rubric: Optional[list[RubricCriteria]] = Field(None, repr=False)
    """
    (Optional) A list of scoring criteria and ratings for each rubric criterion. Included if there is an associated rubric.
    """

    assignment_visibility: Optional[list[int]] = Field(
        None, examples=[[137, 381, 572]], repr=False
    )
    """
    (Optional) If 'assignment_visibility' is included in the 'include' parameter, includes an array of student IDs who can see this assignment.
    """

    overrides: Optional[list[AssignmentOverride]] = Field(None, repr=False)
    """
    (Optional) If 'overrides' is included in the 'include' parameter, includes an array of assignment override objects.
    """

    omit_from_final_grade: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    (Optional) If true, the assignment will be omitted from the student's final grade
    """

    hide_in_gradebook: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    (Optional) If true, the assignment will not be shown in any gradebooks
    """

    moderated_grading: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    Boolean indicating if the assignment is moderated.
    """

    grader_count: Optional[int] = Field(None, examples=[3], repr=False)
    """
    The maximum number of provisional graders who may issue grades for this assignment. Only relevant for moderated assignments. Must be a positive value, and must be set to 1 if the course has fewer than two active instructors. Otherwise, the maximum value is the number of active instructors in the course minus one, or 10 if the course has more than 11 active instructors.
    """

    final_grader_id: Optional[int] = Field(None, examples=[3], repr=False)
    """
    The user ID of the grader responsible for choosing final grades for this assignment. Only relevant for moderated assignments.
    """

    grader_comments_visible_to_graders: Optional[bool] = Field(
        None, examples=[True], repr=False
    )
    """
    Boolean indicating if provisional graders' comments are visible to other provisional graders. Only relevant for moderated assignments.
    """

    graders_anonymous_to_graders: Optional[bool] = Field(
        None, examples=[True], repr=False
    )
    """
    Boolean indicating if provisional graders' identities are hidden from other provisional graders. Only relevant for moderated assignments with grader_comments_visible_to_graders set to true.
    """

    grader_names_visible_to_final_grader: Optional[bool] = Field(
        None, examples=[True], repr=False
    )
    """
    Boolean indicating if provisional grader identities are visible to the final grader. Only relevant for moderated assignments.
    """

    anonymous_grading: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    Boolean indicating if the assignment is graded anonymously. If true, graders cannot see student identities.
    """

    allowed_attempts: Optional[int] = Field(None, examples=[2], repr=False)
    """
    The number of submission attempts a student can make for this assignment. -1 is considered unlimited.
    """

    post_manually: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    Whether the assignment has manual posting enabled. Only relevant for courses using New Gradebook.
    """

    score_statistics: Optional[ScoreStatistic] = Field(None, repr=False)
    """
    (Optional) If 'score_statistics' and 'submission' are included in the 'include' parameter and statistics are available, includes the min, max, and mode for this assignment
    """

    can_submit: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    (Optional) If retrieving a single assignment and 'can_submit' is included in the 'include' parameter, flags whether user has the right to submit the assignment (i.e. checks enrollment dates, submission types, locked status, attempts remaining, etc...). Including 'can submit' automatically includes 'submission' in the include parameter. Not available when observed_users are included.
    """

    ab_guid: Optional[list[str]] = Field(None, examples=[['ABCD', 'EFGH']], repr=False)
    """
    (Optional) The academic benchmark(s) associated with the assignment or the assignment's rubric. Only included if 'ab_guid' is included in the 'include' parameter.
    """

    annotatable_attachment_id: Optional[int] = Field(None, repr=False)
    """
    The id of the attachment to be annotated by students. Relevant only if submission_types includes 'student_annotation'.
    """

    anonymize_students: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    (Optional) Boolean indicating whether student names are anonymized
    """

    require_lockdown_browser: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    (Optional) Boolean indicating whether the Respondus LockDown Browser® is required for this assignment.
    """

    important_dates: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    (Optional) Boolean indicating whether this assignment has important dates.
    """

    muted: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    (Optional, Deprecated) Boolean indicating whether notifications are muted for this assignment.
    """

    anonymous_peer_reviews: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Boolean indicating whether peer reviews are anonymous.
    """

    anonymous_instructor_annotations: Optional[bool] = Field(
        None, examples=[False], repr=False
    )
    """
    Boolean indicating whether instructor anotations are anonymous.
    """

    graded_submissions_exist: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Boolean indicating whether this assignment has graded submissions.
    """

    is_quiz_assignment: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Boolean indicating whether this is a quiz lti assignment.
    """

    in_closed_grading_period: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Boolean indicating whether this assignment is in a closed grading period.
    """

    can_duplicate: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Boolean indicating whether this assignment can be duplicated.
    """

    original_course_id: Optional[int] = Field(None, examples=[4], repr=False)
    """
    If this assignment is a duplicate, it is the original assignment's course_id
    """

    original_assignment_id: Optional[int] = Field(None, examples=[4], repr=False)
    """
    If this assignment is a duplicate, it is the original assignment's id
    """

    original_lti_resource_link_id: Optional[int] = Field(None, examples=[4], repr=False)
    """
    If this assignment is a duplicate, it is the original assignment's lti_resource_link_id
    """

    original_assignment_name: Optional[str] = Field(
        None, examples=['some assignment'], repr=False
    )
    """
    If this assignment is a duplicate, it is the original assignment's name
    """

    original_quiz_id: Optional[int] = Field(None, examples=[4], repr=False)
    """
    If this assignment is a duplicate, it is the original assignment's quiz_id
    """

    workflow_state: Optional[str] = Field(None, examples=['unpublished'], repr=False)
    """
    String indicating what state this assignment is in.
    """




from .discussion_topics import DiscussionTopic  # noqa: E402
from .rubrics import RubricRating as RubricRating_1  # noqa: E402
from .submissions import Submission  # noqa: E402
Assignment.model_rebuild()