# generated by datamodel-codegen:
#   filename:  blueprint_courses.json
#   timestamp: 2024-09-02T14:02:23+00:00

from __future__ import annotations

from datetime import datetime
from typing import Any, Optional

from pydantic import Field

from . import CanvasBaseModel



class BlueprintMigration(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[1])
    """
    The ID of the migration.
    """

    template_id: Optional[int] = Field(None, examples=[2])
    """
    The ID of the template the migration belongs to. Only present when querying a blueprint course.
    """

    subscription_id: Optional[int] = Field(None, examples=[101], repr=False)
    """
    The ID of the associated course's blueprint subscription. Only present when querying a course associated with a blueprint.
    """

    user_id: Optional[int] = Field(None, examples=[3], repr=False)
    """
    The ID of the user who queued the migration.
    """

    workflow_state: Optional[str] = Field(None, examples=['running'], repr=False)
    """
    Current state of the content migration: queued, exporting, imports_queued, completed, exports_failed, imports_failed
    """

    created_at: Optional[datetime] = Field(
        None, examples=['2013-08-28T23:59:00-06:00'], repr=False
    )
    """
    Time when the migration was queued
    """

    exports_started_at: Optional[datetime] = Field(
        None, examples=['2013-08-28T23:59:00-06:00'], repr=False
    )
    """
    Time when the exports begun
    """

    imports_queued_at: Optional[datetime] = Field(
        None, examples=['2013-08-28T23:59:00-06:00'], repr=False
    )
    """
    Time when the exports were completed and imports were queued
    """

    imports_completed_at: Optional[datetime] = Field(
        None, examples=['2013-08-28T23:59:00-06:00'], repr=False
    )
    """
    Time when the imports were completed
    """

    comment: Optional[str] = Field(
        None, examples=['Fixed spelling in question 3 of midterm exam'], repr=False
    )
    """
    User-specified comment describing changes made in this operation
    """



class BlueprintRestriction(CanvasBaseModel):
    content: Optional[bool] = Field(None, examples=[True])
    """
    Restriction on main content (e.g. title, description).
    """

    points: Optional[bool] = Field(None, examples=[True])
    """
    Restriction on points possible for assignments and graded learning objects
    """

    due_dates: Optional[bool] = Field(None, examples=[False])
    """
    Restriction on due dates for assignments and graded learning objects
    """

    availability_dates: Optional[bool] = Field(None, examples=[True])
    """
    Restriction on availability dates for an object
    """



class ChangeRecord(CanvasBaseModel):
    asset_id: Optional[int] = Field(None, examples=[2])
    """
    The ID of the learning object that was changed in the blueprint course.
    """

    asset_type: Optional[str] = Field(None, examples=['assignment'], repr=False)
    """
    The type of the learning object that was changed in the blueprint course.  One of 'assignment', 'attachment', 'discussion_topic', 'external_tool', 'quiz', 'wiki_page', 'syllabus', or 'settings'.  For 'syllabus' or 'settings', the asset_id is the course id.
    """

    asset_name: Optional[str] = Field(None, examples=['Some Assignment'])
    """
    The name of the learning object that was changed in the blueprint course.
    """

    change_type: Optional[str] = Field(None, examples=['created'], repr=False)
    """
    The type of change; one of 'created', 'updated', 'deleted'
    """

    html_url: Optional[str] = Field(
        None,
        examples=['https://canvas.example.com/courses/101/assignments/2'],
        repr=False,
    )
    """
    The URL of the changed object
    """

    locked: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Whether the object is locked in the blueprint
    """

    exceptions: Optional[list[dict[str, Any]]] = Field(
        None,
        examples=[[{'course_id': 101, 'conflicting_changes': ['points']}]],
        repr=False,
    )
    """
    A list of ExceptionRecords for linked courses that did not receive this update.
    """



class ExceptionRecord(CanvasBaseModel):
    course_id: Optional[int] = Field(None, examples=[101])
    """
    The ID of the associated course
    """

    conflicting_changes: Optional[list[dict[str, Any]]] = Field(
        None, examples=[['points']]
    )
    """
    A list of change classes in the associated course's copy of the item that prevented a blueprint change from being applied. One or more of ['content', 'points', 'due_dates', 'availability_dates'].
    """



class BlueprintSubscription(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[101])
    """
    The ID of the blueprint course subscription
    """

    template_id: Optional[int] = Field(None, examples=[1])
    """
    The ID of the blueprint template the associated course is subscribed to
    """

    blueprint_course: Optional[dict[str, Any]] = Field(
        None,
        examples=[
            {
                'id': 2,
                'name': 'Biology 100 Blueprint',
                'course_code': 'BIOL 100 BP',
                'term_name': 'Default term',
            }
        ],
        repr=False,
    )
    """
    The blueprint course subscribed to
    """



class BlueprintTemplate(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[1])
    """
    The ID of the template.
    """

    course_id: Optional[int] = Field(None, examples=[2], repr=False)
    """
    The ID of the Course the template belongs to.
    """

    last_export_completed_at: Optional[datetime] = Field(
        None, examples=['2013-08-28T23:59:00-06:00'], repr=False
    )
    """
    Time when the last export was completed
    """

    associated_course_count: Optional[int] = Field(None, examples=[3], repr=False)
    """
    Number of associated courses for the template
    """

    latest_migration: Optional[BlueprintMigration] = Field(None, repr=False)
    """
    Details of the latest migration
    """

