# generated by datamodel-codegen:
#   filename:  conversations.json
#   timestamp: 2024-09-02T14:02:23+00:00

from __future__ import annotations

from datetime import datetime
from typing import Optional

from pydantic import Field

from . import CanvasBaseModel



class ConversationParticipant(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[2])
    """
    The user ID for the participant.
    """

    name: Optional[str] = Field(None, examples=['Shelly'])
    """
    A short name the user has selected, for use in conversations or other less formal places through the site.
    """

    full_name: Optional[str] = Field(None, examples=['Sheldon Cooper'])
    """
    The full name of the user.
    """

    avatar_url: Optional[str] = Field(
        None, examples=['https://canvas.instructure.com/images/messages/avatar-50.png']
    )
    """
    If requested, this field will be included and contain a url to retrieve the user's avatar.
    """



class Conversation(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[2])
    """
    the unique identifier for the conversation.
    """

    subject: Optional[str] = Field(None, examples=[2])
    """
    the subject of the conversation.
    """

    workflow_state: Optional[str] = Field(None, examples=['unread'], repr=False)
    """
    The current state of the conversation (read, unread or archived).
    """

    last_message: Optional[str] = Field(
        None, examples=["sure thing, here's the file"], repr=False
    )
    """
    A <=100 character preview from the most recent message.
    """

    start_at: Optional[datetime] = Field(
        None, examples=['2011-09-02T12:00:00Z'], repr=False
    )
    """
    the date and time at which the last message was sent.
    """

    message_count: Optional[int] = Field(None, examples=[2], repr=False)
    """
    the number of messages in the conversation.
    """

    subscribed: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    whether the current user is subscribed to the conversation.
    """

    private: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    whether the conversation is private.
    """

    starred: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    whether the conversation is starred.
    """

    properties: Optional[list[str]] = Field(None, repr=False)
    """
    Additional conversation flags (last_author, attachments, media_objects). Each listed property means the flag is set to true (i.e. the current user is the most recent author, there are attachments, or there are media objects)
    """

    audience: Optional[list[int]] = Field(None, repr=False)
    """
    Array of user ids who are involved in the conversation, ordered by participation level, then alphabetical. Excludes current user, unless this is a monologue.
    """

    audience_contexts: Optional[list[str]] = Field(None, repr=False)
    """
    Most relevant shared contexts (courses and groups) between current user and other participants. If there is only one participant, it will also include that user's enrollment(s)/ membership type(s) in each course/group.
    """

    avatar_url: Optional[str] = Field(
        None,
        examples=['https://canvas.instructure.com/images/messages/avatar-group-50.png'],
        repr=False,
    )
    """
    URL to appropriate icon for this conversation (custom, individual or group avatar, depending on audience).
    """

    participants: Optional[list[ConversationParticipant]] = Field(None, repr=False)
    """
    Array of users participating in the conversation. Includes current user.
    """

    visible: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    indicates whether the conversation is visible under the current scope and filter. This attribute is always true in the index API response, and is primarily useful in create/update responses so that you can know if the record should be displayed in the UI. The default scope is assumed, unless a scope or filter is passed to the create/update API call.
    """

    context_name: Optional[str] = Field(None, examples=['Canvas 101'], repr=False)
    """
    Name of the course or group in which the conversation is occurring.
    """

