# generated by datamodel-codegen:
#   filename:  enrollments.json
#   timestamp: 2024-09-02T14:02:23+00:00

from __future__ import annotations

from datetime import datetime
from typing import Optional

from pydantic import Field

from . import CanvasBaseModel



class Grade(CanvasBaseModel):
    html_url: Optional[str] = Field(None, examples=[''])
    """
    The URL to the Canvas web UI page for the user's grades, if this is a student enrollment.
    """

    current_grade: Optional[str] = Field(None, examples=[''])
    """
    The user's current grade in the class. Only included if user has permissions to view this grade.
    """

    final_grade: Optional[str] = Field(None, examples=[''])
    """
    The user's final grade for the class. Only included if user has permissions to view this grade.
    """

    current_score: Optional[str] = Field(None, examples=[''])
    """
    The user's current score in the class. Only included if user has permissions to view this score.
    """

    final_score: Optional[str] = Field(None, examples=[''])
    """
    The user's final score for the class. Only included if user has permissions to view this score.
    """

    current_points: Optional[int] = Field(None, examples=[150])
    """
    The total points the user has earned in the class. Only included if user has permissions to view this score and 'current_points' is passed in the request's 'include' parameter.
    """

    unposted_current_grade: Optional[str] = Field(None, examples=[''])
    """
    The user's current grade in the class including muted/unposted assignments. Only included if user has permissions to view this grade, typically teachers, TAs, and admins.
    """

    unposted_final_grade: Optional[str] = Field(None, examples=[''])
    """
    The user's final grade for the class including muted/unposted assignments. Only included if user has permissions to view this grade, typically teachers, TAs, and admins..
    """

    unposted_current_score: Optional[str] = Field(None, examples=[''])
    """
    The user's current score in the class including muted/unposted assignments. Only included if user has permissions to view this score, typically teachers, TAs, and admins..
    """

    unposted_final_score: Optional[str] = Field(None, examples=[''])
    """
    The user's final score for the class including muted/unposted assignments. Only included if user has permissions to view this score, typically teachers, TAs, and admins..
    """

    unposted_current_points: Optional[int] = Field(None, examples=[150])
    """
    The total points the user has earned in the class, including muted/unposted assignments. Only included if user has permissions to view this score (typically teachers, TAs, and admins) and 'current_points' is passed in the request's 'include' parameter.
    """



class Enrollment(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[1])
    """
    The ID of the enrollment.
    """

    course_id: Optional[int] = Field(None, examples=[1], repr=False)
    """
    The unique id of the course.
    """

    sis_course_id: Optional[str] = Field(None, examples=['SHEL93921'], repr=False)
    """
    The SIS Course ID in which the enrollment is associated. Only displayed if present. This field is only included if the user has permission to view SIS information.
    """

    course_integration_id: Optional[str] = Field(
        None, examples=['SHEL93921'], repr=False
    )
    """
    The Course Integration ID in which the enrollment is associated. This field is only included if the user has permission to view SIS information.
    """

    course_section_id: Optional[int] = Field(None, examples=[1], repr=False)
    """
    The unique id of the user's section.
    """

    section_integration_id: Optional[str] = Field(
        None, examples=['SHEL93921'], repr=False
    )
    """
    The Section Integration ID in which the enrollment is associated. This field is only included if the user has permission to view SIS information.
    """

    sis_account_id: Optional[str] = Field(None, examples=['SHEL93921'], repr=False)
    """
    The SIS Account ID in which the enrollment is associated. Only displayed if present. This field is only included if the user has permission to view SIS information.
    """

    sis_section_id: Optional[str] = Field(None, examples=['SHEL93921'], repr=False)
    """
    The SIS Section ID in which the enrollment is associated. Only displayed if present. This field is only included if the user has permission to view SIS information.
    """

    sis_user_id: Optional[str] = Field(None, examples=['SHEL93921'], repr=False)
    """
    The SIS User ID in which the enrollment is associated. Only displayed if present. This field is only included if the user has permission to view SIS information.
    """

    enrollment_state: Optional[str] = Field(None, examples=['active'], repr=False)
    """
    The state of the user's enrollment in the course.
    """

    limit_privileges_to_course_section: Optional[bool] = Field(
        None, examples=[True], repr=False
    )
    """
    User can only access his or her own course section.
    """

    sis_import_id: Optional[int] = Field(None, examples=[83], repr=False)
    """
    The unique identifier for the SIS import. This field is only included if the user has permission to manage SIS information.
    """

    root_account_id: Optional[int] = Field(None, examples=[1], repr=False)
    """
    The unique id of the user's account.
    """

    type: Optional[str] = Field(None, examples=['StudentEnrollment'])
    """
    The enrollment type. One of 'StudentEnrollment', 'TeacherEnrollment', 'TaEnrollment', 'DesignerEnrollment', 'ObserverEnrollment'.
    """

    user_id: Optional[int] = Field(None, examples=[1], repr=False)
    """
    The unique id of the user.
    """

    associated_user_id: Optional[int] = Field(None, examples=[None], repr=False)
    """
    The unique id of the associated user. Will be null unless type is ObserverEnrollment.
    """

    role: Optional[str] = Field(None, examples=['StudentEnrollment'], repr=False)
    """
    The enrollment role, for course-level permissions. This field will match `type` if the enrollment role has not been customized.
    """

    role_id: Optional[int] = Field(None, examples=[1], repr=False)
    """
    The id of the enrollment role.
    """

    created_at: Optional[datetime] = Field(
        None, examples=['2012-04-18T23:08:51Z'], repr=False
    )
    """
    The created time of the enrollment, in ISO8601 format.
    """

    updated_at: Optional[datetime] = Field(
        None, examples=['2012-04-18T23:08:51Z'], repr=False
    )
    """
    The updated time of the enrollment, in ISO8601 format.
    """

    start_at: Optional[datetime] = Field(
        None, examples=['2012-04-18T23:08:51Z'], repr=False
    )
    """
    The start time of the enrollment, in ISO8601 format.
    """

    end_at: Optional[datetime] = Field(
        None, examples=['2012-04-18T23:08:51Z'], repr=False
    )
    """
    The end time of the enrollment, in ISO8601 format.
    """

    last_activity_at: Optional[datetime] = Field(
        None, examples=['2012-04-18T23:08:51Z'], repr=False
    )
    """
    The last activity time of the user for the enrollment, in ISO8601 format.
    """

    last_attended_at: Optional[datetime] = Field(
        None, examples=['2012-04-18T23:08:51Z'], repr=False
    )
    """
    The last attended date of the user for the enrollment in a course, in ISO8601 format.
    """

    total_activity_time: Optional[int] = Field(None, examples=[260], repr=False)
    """
    The total activity time of the user for the enrollment, in seconds.
    """

    html_url: Optional[str] = Field(None, examples=['https://...'], repr=False)
    """
    The URL to the Canvas web UI page for this course enrollment.
    """

    grades: Optional[Grade] = Field(
        None,
        examples=[
            {
                'html_url': 'https://...',
                'current_score': 35,
                'current_grade': None,
                'final_score': 6.67,
                'final_grade': None,
            }
        ],
        repr=False,
    )
    """
    The URL to the Canvas web UI page containing the grades associated with this enrollment.
    """

    user: Optional[User] = Field(
        None,
        examples=[
            {
                'id': 3,
                'name': 'Student 1',
                'sortable_name': '1, Student',
                'short_name': 'Stud 1',
            }
        ],
        repr=False,
    )
    """
    A description of the user.
    """

    override_grade: Optional[str] = Field(None, examples=['A'], repr=False)
    """
    The user's override grade for the course.
    """

    override_score: Optional[float] = Field(None, examples=[99.99], repr=False)
    """
    The user's override score for the course.
    """

    unposted_current_grade: Optional[str] = Field(None, examples=[''], repr=False)
    """
    The user's current grade in the class including muted/unposted assignments. Only included if user has permissions to view this grade, typically teachers, TAs, and admins.
    """

    unposted_final_grade: Optional[str] = Field(None, examples=[''], repr=False)
    """
    The user's final grade for the class including muted/unposted assignments. Only included if user has permissions to view this grade, typically teachers, TAs, and admins..
    """

    unposted_current_score: Optional[str] = Field(None, examples=[''], repr=False)
    """
    The user's current score in the class including muted/unposted assignments. Only included if user has permissions to view this score, typically teachers, TAs, and admins..
    """

    unposted_final_score: Optional[str] = Field(None, examples=[''], repr=False)
    """
    The user's final score for the class including muted/unposted assignments. Only included if user has permissions to view this score, typically teachers, TAs, and admins..
    """

    has_grading_periods: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    optional: Indicates whether the course the enrollment belongs to has grading periods set up. (applies only to student enrollments, and only available in course endpoints)
    """

    totals_for_all_grading_periods_option: Optional[bool] = Field(
        None, examples=[True], repr=False
    )
    """
    optional: Indicates whether the course the enrollment belongs to has the Display Totals for 'All Grading Periods' feature enabled. (applies only to student enrollments, and only available in course endpoints)
    """

    current_grading_period_title: Optional[str] = Field(
        None, examples=['Fall Grading Period'], repr=False
    )
    """
    optional: The name of the currently active grading period, if one exists. If the course the enrollment belongs to does not have grading periods, or if no currently active grading period exists, the value will be null. (applies only to student enrollments, and only available in course endpoints)
    """

    current_grading_period_id: Optional[int] = Field(None, examples=[5], repr=False)
    """
    optional: The id of the currently active grading period, if one exists. If the course the enrollment belongs to does not have grading periods, or if no currently active grading period exists, the value will be null. (applies only to student enrollments, and only available in course endpoints)
    """

    current_period_override_grade: Optional[str] = Field(
        None, examples=['A'], repr=False
    )
    """
    The user's override grade for the current grading period.
    """

    current_period_override_score: Optional[float] = Field(
        None, examples=[99.99], repr=False
    )
    """
    The user's override score for the current grading period.
    """

    current_period_unposted_current_score: Optional[float] = Field(
        None, examples=[95.8], repr=False
    )
    """
    optional: The student's score in the course for the current grading period, including muted/unposted assignments. Only included if user has permission to view this score, typically teachers, TAs, and admins. If the course the enrollment belongs to does not have grading periods, or if no currently active grading period exists, the value will be null. (applies only to student enrollments, and only available in course endpoints)
    """

    current_period_unposted_final_score: Optional[float] = Field(
        None, examples=[85.25], repr=False
    )
    """
    optional: The student's score in the course for the current grading period, including muted/unposted assignments and including ungraded assignments with a score of 0. Only included if user has permission to view this score, typically teachers, TAs, and admins. If the course the enrollment belongs to does not have grading periods, or if no currently active grading period exists, the value will be null. (applies only to student enrollments, and only available in course endpoints)
    """

    current_period_unposted_current_grade: Optional[str] = Field(
        None, examples=['A'], repr=False
    )
    """
    optional: The letter grade equivalent of current_period_unposted_current_score, if available. Only included if user has permission to view this grade, typically teachers, TAs, and admins. If the course the enrollment belongs to does not have grading periods, or if no currently active grading period exists, the value will be null. (applies only to student enrollments, and only available in course endpoints)
    """

    current_period_unposted_final_grade: Optional[str] = Field(
        None, examples=['B'], repr=False
    )
    """
    optional: The letter grade equivalent of current_period_unposted_final_score, if available. Only included if user has permission to view this grade, typically teachers, TAs, and admins. If the course the enrollment belongs to does not have grading periods, or if no currently active grading period exists, the value will be null. (applies only to student enrollments, and only available in course endpoints)
    """




from .users import User  # noqa: E402
Enrollment.model_rebuild()