# generated by datamodel-codegen:
#   filename:  groups.json
#   timestamp: 2024-09-02T14:02:23+00:00

from __future__ import annotations

from datetime import datetime
from typing import Any, Optional

from pydantic import Field

from . import CanvasBaseModel



class GroupMembership(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[92])
    """
    The id of the membership object
    """

    group_id: Optional[int] = Field(None, examples=[17])
    """
    The id of the group object to which the membership belongs
    """

    user_id: Optional[int] = Field(None, examples=[3])
    """
    The id of the user object to which the membership belongs
    """

    workflow_state: Optional[str] = Field(None, examples=['accepted'], repr=False)
    """
    The current state of the membership. Current possible values are 'accepted', 'invited', and 'requested'
    """

    moderator: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    Whether or not the user is a moderator of the group (the must also be an active member of the group to moderate)
    """

    just_created: Optional[bool] = Field(None, examples=[True], repr=False)
    """
    optional: whether or not the record was just created on a create call (POST), i.e. was the user just added to the group, or was the user already a member
    """

    sis_import_id: Optional[int] = Field(None, examples=[4], repr=False)
    """
    The id of the SIS import if created through SIS. Only included if the user has permission to manage SIS information.
    """



class Group(CanvasBaseModel):
    id: Optional[int] = Field(None, examples=[17])
    """
    The ID of the group.
    """

    name: Optional[str] = Field(None, examples=['Math Group 1'])
    """
    The display name of the group.
    """

    description: Optional[str] = Field(None, repr=False)
    """
    A description of the group. This is plain text.
    """

    is_public: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Whether or not the group is public.  Currently only community groups can be made public.  Also, once a group has been set to public, it cannot be changed back to private.
    """

    followed_by_user: Optional[bool] = Field(None, examples=[False], repr=False)
    """
    Whether or not the current user is following this group.
    """

    join_level: Optional[str] = Field(None, examples=['invitation_only'], repr=False)
    """
    How people are allowed to join the group.  For all groups except for community groups, the user must share the group's parent course or account.  For student organized or community groups, where a user can be a member of as many or few as they want, the applicable levels are 'parent_context_auto_join', 'parent_context_request', and 'invitation_only'.  For class groups, where students are divided up and should only be part of one group of the category, this value will always be 'invitation_only', and is not relevant. * If 'parent_context_auto_join', anyone can join and will be automatically accepted. * If 'parent_context_request', anyone  can request to join, which must be approved by a group moderator. * If 'invitation_only', only those how have received an invitation my join the group, by accepting that invitation.
    """

    members_count: Optional[int] = Field(None, examples=[0], repr=False)
    """
    The number of members currently in the group
    """

    avatar_url: Optional[str] = Field(
        None, examples=['https://<canvas>/files/avatar_image.png'], repr=False
    )
    """
    The url of the group's avatar
    """

    context_type: Optional[str] = Field(None, examples=['Course'], repr=False)
    """
    The course or account that the group belongs to. The pattern here is that whatever the context_type is, there will be an _id field named after that type. So if instead context_type was 'account', the course_id field would be replaced by an account_id field.
    """

    course_id: Optional[int] = Field(None, examples=[3], repr=False)
    role: Optional[str] = Field(None, repr=False)
    """
    Certain types of groups have special role designations. Currently, these include: 'communities', 'student_organized', and 'imported'. Regular course/account groups have a role of null.
    """

    group_category_id: Optional[int] = Field(None, examples=[4], repr=False)
    """
    The ID of the group's category.
    """

    sis_group_id: Optional[str] = Field(None, examples=['group4a'], repr=False)
    """
    The SIS ID of the group. Only included if the user has permission to view SIS information.
    """

    sis_import_id: Optional[int] = Field(None, examples=[14], repr=False)
    """
    The id of the SIS import if created through SIS. Only included if the user has permission to manage SIS information.
    """

    storage_quota_mb: Optional[int] = Field(None, examples=[50], repr=False)
    """
    the storage quota for the group, in megabytes
    """

    permissions: Optional[dict[str, Any]] = Field(
        None,
        examples=[{'create_discussion_topic': True, 'create_announcement': True}],
        repr=False,
    )
    """
    optional: the permissions the user has for the group. returned only for a single group and include[]=permissions
    """

    users: Optional[list[User]] = Field(None, repr=False)
    """
    optional: A list of users that are members in the group. Returned only if include[]=users. WARNING: this collection's size is capped (if there are an extremely large number of users in the group (thousands) not all of them will be returned).  If you need to capture all the users in a group with certainty consider using the paginated /api/v1/groups/<group_id>/memberships endpoint.
    """




from .users import User  # noqa: E402
Group.model_rebuild()